package com.naver.domain;

import java.net.URLEncoder;

import org.springframework.web.util.UriComponents;
import org.springframework.web.util.UriComponentsBuilder;

public class PageMaker {
	private int totalCount; //전체글수
	private int startPage;  //시작페이지
	private int endPage;    //끝페이지
	private boolean prev;   //이전구간 마지막페이지
	private boolean next;   //다음구간 첫페이지
	private int displayPageNum=10; //보여줄 페이지수
	private Criteria cri;   //Criteria.
	
	//cri초기화
	public void setCri(Criteria cri){
		this.cri=cri;
	}
	//전체글수
	public void setTotalCount(int totalCount){
		this.totalCount=totalCount;
		
		//calData()호출
		this.calData();
	}
	//시작페이지.끝페이지.이전.다음 계산
	private void calData(){
		//끝페이지
		endPage=(int)(Math.ceil(cri.getPage()/(double)displayPageNum)*displayPageNum);
		//시작페이지
		startPage=(endPage-displayPageNum)+1;
		//실제끝페이지
		int tempEndPage=(int)(Math.ceil(totalCount)/(double)cri.getPerPageNum());
		//실제끝페이지보다 endPage가 크면,endPage재조정
		if(endPage>tempEndPage){
			endPage=tempEndPage;
		}
		//이전구간 첫페이지
		prev=(startPage==1?false:true);
		next=(endPage*cri.getPerPageNum()>=totalCount?false:true);
		
		
		
	}
	public int getStartPage() {
		return startPage;
	}
	public void setStartPage(int startPage) {
		this.startPage = startPage;
	}
	public int getEndPage() {
		return endPage;
	}
	public void setEndPage(int endPage) {
		this.endPage = endPage;
	}
	public boolean isPrev() {
		return prev;
	}
	public void setPrev(boolean prev) {
		this.prev = prev;
	}
	public boolean isNext() {
		return next;
	}
	public void setNext(boolean next) {
		this.next = next;
	}
	public int getDisplayPageNum() {
		return displayPageNum;
	}
	public void setDisplayPageNum(int displayPageNum) {
		this.displayPageNum = displayPageNum;
	}
	public int getTotalCount() {
		return totalCount;
	}
	public Criteria getCri() {
		return cri;
	}
	@Override
	public String toString() {
		return "PageMaker [totalCount=" + totalCount + ", startPage=" + startPage + ", endPage=" + endPage + ", prev="
				+ prev + ", next=" + next + ", displayPageNum=" + displayPageNum + ", cri=" + cri + "]";
	}
	
	//page=1&perPageNum=20 형태의 패러미터생성
	public String makeQuery(int page){
		UriComponents uriComponents=UriComponentsBuilder.newInstance()
									.queryParam("page", page)
									.queryParam("perPageNum", cri.getPerPageNum())
									.build();
		return uriComponents.toUriString();
		
	}
	
	//page=1&perPageNum=20&SearchType=t&keyword=java
	//형태의 패러미터생성
	public String makeSearch(int page){
			UriComponents uriComponents=UriComponentsBuilder.newInstance()
										.queryParam("page", page)
										.queryParam("perPageNum", cri.getPerPageNum())
										.queryParam("searchType", ((SearchCriteria)cri).getSearchType())
										.queryParam("keyword", encoding(((SearchCriteria)cri).getKeyword()))
										.build();
			return uriComponents.toUriString();
	}
	
	// UTF-8로 인코딩
	private String encoding(String keyword){
		//검색어가 null이거나 빈문자열이면 종료
		if(keyword==null||keyword.trim().length()==0){
			return "";
		}
		try{
			return URLEncoder.encode(keyword,"UTF-8");
		}catch(Exception e){
			return "";
		}
	}
}
