package com.naver.myboard;

import javax.inject.Inject;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.servlet.mvc.support.RedirectAttributes;

import com.naver.domain.BoardVO;
import com.naver.domain.Criteria;
import com.naver.domain.PageMaker;
import com.naver.service.BoardService;

@Controller
@RequestMapping("/board/*")
public class BoardController {
	private static Logger logger=LoggerFactory.getLogger(BoardController.class);
	
	@Inject
	private BoardService service;
	
	@RequestMapping(value="/register",method=RequestMethod.GET)
	public void registerGET(BoardVO vo,Model model) throws Exception{
		logger.info("register get...");
	}
	
	@RequestMapping(value="/register",method=RequestMethod.POST)
	public String registerPOST(BoardVO vo,RedirectAttributes rttr) throws Exception{
		logger.info(vo.toString());
		
		service.regist(vo);
		
		// success페이지로 이동
		//return "redirect:/board/success";
		
		// 등록페이지에서 목록으로 넘어갔는지 체크하는 Flag
		rttr.addFlashAttribute("result", "success");
		
		// listAll페이지로 이동
		return "redirect:/board/listAll";
	}
	
	@RequestMapping(value="/success",method=RequestMethod.GET)
	public void successGET() throws Exception{
		logger.info("success get...");
	}
	
//	@RequestMapping(value="/listAll",method=RequestMethod.GET)
//	public void listAll(Model model) throws Exception{
//		logger.info("listAll....");
//		model.addAttribute("list", service.listAll());
//	}
	
//	@RequestMapping(value="/read",method=RequestMethod.GET)
//	public void read(@RequestParam("bno") int bno,Model model) throws Exception
//	{
//		model.addAttribute(service.read(bno));
//	}
	@RequestMapping(value="/listPage",method=RequestMethod.GET)
	public void listPage(@ModelAttribute("cri") Criteria cri,Model model) throws Exception{
		logger.info("listPage....");
		//list전달
		model.addAttribute("list", service.listCriteria(cri));
		//pageMaker전달
		PageMaker pageMaker=new PageMaker();
		pageMaker.setCri(cri);
		pageMaker.setTotalCount(service.listCountCriteria(cri));
		model.addAttribute("pageMaker", pageMaker);
	}
	@RequestMapping(value="/readPage",method=RequestMethod.GET)
	public void read(@RequestParam("bno") int bno,
			@ModelAttribute("cri") Criteria cri,Model model) throws Exception{
		PageMaker pageMaker=new PageMaker();
		pageMaker.setCri(cri);
		model.addAttribute("pageMaker", pageMaker);
		model.addAttribute(service.read(bno));
	}
	
	@RequestMapping(value="/remove",method=RequestMethod.POST)
	public String registerPOST(@RequestParam("bno") int bno,RedirectAttributes rttr) throws Exception{
				
		service.remove(bno);
		
		// success페이지로 이동
		//return "redirect:/board/success";
		
		// 등록페이지에서 목록으로 넘어갔는지 체크하는 Flag
		rttr.addFlashAttribute("result", "success");
		
		// listAll페이지로 이동
		return "redirect:/board/listAll";
	}
	@RequestMapping(value="/modify",method=RequestMethod.GET)
	public void modifyGet(@RequestParam("bno") int bno, Model model) throws Exception{
		model.addAttribute(service.read(bno));
	}
	@RequestMapping(value="/modify",method=RequestMethod.POST)
	public String modifyPOST(BoardVO vo,RedirectAttributes rttr) throws Exception{
		service.modify(vo);
		
		// 등록페이지에서 목록으로 넘어갔는지 체크하는 Flag
		rttr.addFlashAttribute("result", "success");
				
		// listAll페이지로 이동
		return "redirect:/board/listAll";
		
	} 
	
	//테스트용
	@RequestMapping(value="/listCri",method=RequestMethod.GET)
	public void listAll(Criteria cri,Model model) throws Exception{
		logger.info("listAll....");
		model.addAttribute("list", service.listCriteria(cri));
	}
	
	
	
	
	
}
