package com.naver.myboard;

import javax.inject.Inject;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.servlet.mvc.support.RedirectAttributes;

import com.naver.domain.BoardVO;
import com.naver.domain.Criteria;
import com.naver.domain.PageMaker;
import com.naver.domain.SearchCriteria;
import com.naver.service.BoardService;

@Controller
@RequestMapping("/sboard/*")
public class SearchBoardController {
	
	private static Logger logger=LoggerFactory.getLogger(SearchBoardController.class);
	
	@Inject
	private BoardService service;
	
	@RequestMapping(value="/list",method=RequestMethod.GET)
	public void listPage(@ModelAttribute("cri") SearchCriteria cri,
						Model model
			) throws Exception{
		logger.info(cri.toString());
		
//		model.addAttribute("list", service.listCriteria(cri));
		model.addAttribute("list",service.listSearchCriteria(cri));
		
		PageMaker pageMaker=new PageMaker();
		pageMaker.setCri(cri);
//		pageMaker.setTotalCount(service.listCountCriteria(cri));
		pageMaker.setTotalCount(service.listSearchCount(cri));
		model.addAttribute("pageMaker", pageMaker);
	}
	
	@RequestMapping(value="/readPage",method=RequestMethod.GET)
	public void read(@RequestParam("bno") int bno,
			@ModelAttribute("cri") SearchCriteria cri,Model model) throws Exception{
		PageMaker pageMaker=new PageMaker();
		pageMaker.setCri(cri);
		model.addAttribute("pageMaker", pageMaker);
		model.addAttribute(service.read(bno));
	}
	
	@RequestMapping(value="/removePage",method=RequestMethod.POST)
	public String registerPOST(@RequestParam("bno") int bno,
			SearchCriteria cri,
			RedirectAttributes rttr) throws Exception{
				
		service.remove(bno);
		
		// success페이지로 이동
		//return "redirect:/board/success";
		
		rttr.addAttribute("page",cri.getPage());
		rttr.addAttribute("perPageNum",cri.getPerPageNum());
		rttr.addAttribute("searchType",cri.getSearchType());
		rttr.addAttribute("keyword",cri.getKeyword());
		// 등록페이지에서 목록으로 넘어갔는지 체크하는 Flag
		rttr.addFlashAttribute("result", "success");
		
		// listAll페이지로 이동
		return "redirect:/sboard/list";
	}

	@RequestMapping(value="/modifyPage",method=RequestMethod.GET)
	public void modifyGet(@RequestParam("bno") int bno,
			@ModelAttribute("cri") SearchCriteria cri,
			Model model) throws Exception{
		model.addAttribute(service.read(bno));
	}
	@RequestMapping(value="/modifyPage",method=RequestMethod.POST)
	public String modifyPOST(BoardVO vo,
			@ModelAttribute("cri") SearchCriteria cri,
			RedirectAttributes rttr) throws Exception{
		service.modify(vo);
		
		rttr.addAttribute("page",cri.getPage());
		rttr.addAttribute("perPageNum",cri.getPerPageNum());
		rttr.addAttribute("searchType",cri.getSearchType());
		rttr.addAttribute("keyword",cri.getKeyword());
		
		
		
		// 등록페이지에서 목록으로 넘어갔는지 체크하는 Flag
		rttr.addFlashAttribute("result", "success");
				
		// listAll페이지로 이동
		return "redirect:/sboard/list";
		
	} 
	
	@RequestMapping(value="/register",method=RequestMethod.GET)
	public void registerGET(BoardVO vo,Model model) throws Exception{
		logger.info("register get...");
	}
	
	@RequestMapping(value="/register",method=RequestMethod.POST)
	public String registerPOST(BoardVO vo,RedirectAttributes rttr) throws Exception{
		logger.info(vo.toString());
		
		service.regist(vo);
		
		// success페이지로 이동
		//return "redirect:/board/success";
		
		// 등록페이지에서 목록으로 넘어갔는지 체크하는 Flag
		rttr.addFlashAttribute("result", "success");
		
		// listAll페이지로 이동
		return "redirect:/sboard/list";
	}
	
	
}

